@@ -1,28 +1,7 @@
 //! Interact with `cargo`
 
-/// The absolute path to a binary target's executable.
-///
-/// The `bin_target_name` is the name of the binary
-/// target, exactly as-is.
-///
-/// **NOTE:** This is only set when building an integration test or benchmark.
-///
-/// ## Example
-///
-/// ```rust,no_run
-/// #[test]
-/// fn cli_tests() {
-///     trycmd::TestCases::new()
-///         .default_bin_path(trycmd::cargo_bin!("bin-fixture"))
-///         .case("tests/cmd/*.trycmd");
-/// }
-/// ```
-#[macro_export]
-macro_rules! cargo_bin {
-    ($bin_target_name:expr) => {
-        ::std::path::Path::new(env!(concat!("CARGO_BIN_EXE_", $bin_target_name)))
-    };
-}
+#[doc(inline)]
+pub use snapbox::cmd::cargo_bin;
 
 #[cfg(feature = "examples")]
 pub use examples::{compile_example, compile_examples};
@@ -31,7 +10,7 @@ pub use examples::{compile_example, compile_examples};
 pub(crate) mod examples {
     /// Prepare an example for testing
     ///
-    /// Unlike [`cargo_bin!`][crate::cargo_bin!], this does not inherit all of the current compiler settings.  It
+    /// Unlike `cargo_bin!`, this does not inherit all of the current compiler settings.  It
     /// will match the current target and profile but will not get feature flags.  Pass those arguments
     /// to the compiler via `args`.
     ///
@@ -56,7 +35,7 @@ pub(crate) mod examples {
         target_name: &str,
         args: impl IntoIterator<Item = &'a str>,
     ) -> Result<crate::schema::Bin, crate::Error> {
-        debug!("Compiling example {}", target_name);
+        snapbox::debug!("Compiling example {}", target_name);
         let messages = escargot::CargoBuild::new()
             .current_target()
             .current_release()
@@ -69,7 +48,7 @@ pub(crate) mod examples {
             let message = message
                 .decode()
                 .map_err(|e| crate::Error::new(e.to_string()))?;
-            debug!("Message: {:?}", message);
+            snapbox::debug!("Message: {:?}", message);
             if let Some(bin) = decode_example_message(&message) {
                 let (name, bin) = bin?;
                 assert_eq!(target_name, name);
@@ -85,7 +64,7 @@ pub(crate) mod examples {
 
     /// Prepare all examples for testing
     ///
-    /// Unlike [`cargo_bin!`][crate::cargo_bin!], this does not inherit all of the current compiler settings.  It
+    /// Unlike `cargo_bin!`, this does not inherit all of the current compiler settings.  It
     /// will match the current target and profile but will not get feature flags.  Pass those arguments
     /// to the compiler via `args`.
     ///
@@ -102,7 +81,7 @@ pub(crate) mod examples {
     pub fn compile_examples<'a>(
         args: impl IntoIterator<Item = &'a str>,
     ) -> Result<impl Iterator<Item = (String, crate::schema::Bin)>, crate::Error> {
-        debug!("Compiling examples");
+        snapbox::debug!("Compiling examples");
         let mut examples = std::collections::BTreeMap::new();
 
         let messages = escargot::CargoBuild::new()
@@ -117,7 +96,7 @@ pub(crate) mod examples {
             let message = message
                 .decode()
                 .map_err(|e| crate::Error::new(e.to_string()))?;
-            debug!("Message: {:?}", message);
+            snapbox::debug!("Message: {:?}", message);
             if let Some(bin) = decode_example_message(&message) {
                 let (name, bin) = bin?;
                 examples.insert(name.to_owned(), bin);
@@ -172,27 +151,3 @@ pub(crate) mod examples {
         target.crate_types == ["bin"] && target.kind == ["example"]
     }
 }
-
-/// Look up the path to a cargo-built binary within an integration test.
-///
-/// **NOTE:** Prefer `trycmd::cargo_bin!` as this makes assumptions about cargo
-pub(crate) fn cargo_bin(name: &str) -> std::path::PathBuf {
-    let file_name = format!("{}{}", name, std::env::consts::EXE_SUFFIX);
-    let target_dir = target_dir();
-    target_dir.join(&file_name)
-}
-
-// Adapted from
-// https://github.com/rust-lang/cargo/blob/485670b3983b52289a2f353d589c57fae2f60f82/tests/testsuite/support/mod.rs#L507
-fn target_dir() -> std::path::PathBuf {
-    std::env::current_exe()
-        .ok()
-        .map(|mut path| {
-            path.pop();
-            if path.ends_with("deps") {
-                path.pop();
-            }
-            path
-        })
-        .unwrap()
-}
